<?php

namespace Drupal\commerce_favorites\Cache\Context;

use Drupal\commerce_favorites\FavoritesProviderInterface;
use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Cache\Context\CacheContextInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines the FavoritesCacheContext service, for "per favorites" caching.
 *
 * Cache context ID: 'favorites'.
 */
class FavoritesCacheContext implements CacheContextInterface {

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $account;

  /**
   * The favorites provider service.
   *
   * @var \Drupal\commerce_favorites\FavoritesProviderInterface
   */
  protected $favoritesProvider;

  /**
   * Constructs a new FavoritesCacheContext object.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The current user account.
   * @param \Drupal\commerce_favorites\FavoritesProviderInterface $favorites_provider
   *   The favorites provider service.
   */
  public function __construct(AccountInterface $account, FavoritesProviderInterface $favorites_provider) {
    $this->account = $account;
    $this->favoritesProvider = $favorites_provider;
  }

  /**
   * {@inheritdoc}
   */
  public static function getLabel() {
    return t('Current favorites IDs');
  }

  /**
   * {@inheritdoc}
   */
  public function getContext() {
    return implode(':', $this->favoritesProvider->getFavoritesIds($this->account));
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata() {
    $metadata = new CacheableMetadata();
    foreach ($this->favoritesProvider->getFavoritesLists($this->account) as $favorites) {
      $metadata->addCacheableDependency($favorites);
    }
    return $metadata;
  }

}
