<?php

namespace Drupal\commerce_favorites\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\profile\Entity\ProfileInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Defines the interface for favorites_lists.
 */
interface FavoritesInterface extends ContentEntityInterface, EntityChangedInterface, EntityOwnerInterface {

  /**
   * Gets the favorites code.
   *
   * @return string
   *   The favorites code.
   */
  public function getCode();

  /**
   * Sets the favorites code.
   *
   * @param string $code
   *   The favorites code.
   *
   * @return $this
   */
  public function setCode($code);

  /**
   * Gets the favorites name.
   *
   * @return string
   *   The favorites name.
   */
  public function getName();

  /**
   * Sets the favorites name.
   *
   * @param string $name
   *   The favorites name.
   *
   * @return $this
   */
  public function setName($name);

  /**
   * Gets the shipping profile.
   *
   * @return \Drupal\profile\Entity\ProfileInterface|null
   *   The shipping profile, or null.
   */
  public function getShippingProfile();

  /**
   * Sets the shipping profile.
   *
   * @param \Drupal\profile\Entity\ProfileInterface $profile
   *   The shipping profile.
   *
   * @return $this
   */
  public function setShippingProfile(ProfileInterface $profile);

  /**
   * Gets the favorites items.
   *
   * @return \Drupal\commerce_favorites\Entity\FavoritesItemInterface[]
   *   The favorites items.
   */
  public function getItems();

  /**
   * Sets the favorites items.
   *
   * @param \Drupal\commerce_favorites\Entity\FavoritesItemInterface[] $favorites_items
   *   The favorites items.
   *
   * @return $this
   */
  public function setItems(array $favorites_items);

  /**
   * Gets whether the favorites has favorites items.
   *
   * @return bool
   *   TRUE if the favorites has favorites items, FALSE otherwise.
   */
  public function hasItems();

  /**
   * Adds an favorites item.
   *
   * @param \Drupal\commerce_favorites\Entity\FavoritesItemInterface $favorites_item
   *   The favorites item.
   *
   * @return $this
   */
  public function addItem(FavoritesItemInterface $favorites_item);

  /**
   * Removes an favorites item.
   *
   * @param \Drupal\commerce_favorites\Entity\FavoritesItemInterface $favorites_item
   *   The favorites item.
   *
   * @return $this
   */
  public function removeItem(FavoritesItemInterface $favorites_item);

  /**
   * Checks whether the favorites has a given favorites item.
   *
   * @param \Drupal\commerce_favorites\Entity\FavoritesItemInterface $favorites_item
   *   The favorites item.
   *
   * @return bool
   *   TRUE if the favorites item was found, FALSE otherwise.
   */
  public function hasItem(FavoritesItemInterface $favorites_item);

  /**
   * Gets whether this is the user's default favorites.
   *
   * @return bool
   *   TRUE if this is the user's default favorites, FALSE otherwise.
   */
  public function isDefault();

  /**
   * Sets whether this is the user's default favorites.
   *
   * @param bool $default
   *   Whether this is the user's default favorites.
   *
   * @return $this
   */
  public function setDefault($default);

  /**
   * Gets whether the favorites is public.
   *
   * @return bool
   *   TRUE if the favorites is public, FALSE otherwise.
   */
  public function isPublic();

  /**
   * Sets whether the favorites is public.
   *
   * @param bool $public
   *   Whether the favorites is public.
   *
   * @return $this
   */
  public function setPublic($public);

  /**
   * Gets whether items should remain in the favorites once purchased.
   *
   * @return bool
   *   TRUE if purchased items should remain in the favorites, FALSE otherwise.
   */
  public function getKeepPurchasedItems();

  /**
   * Sets whether items should remain in the favorites once purchased.
   *
   * @param bool $keep_purchased_items
   *   Whether items should remain in the favorites once purchased.
   *
   * @return $this
   */
  public function setKeepPurchasedItems($keep_purchased_items);

  /**
   * Gets the favorites creation timestamp.
   *
   * @return int
   *   Creation timestamp of the favorites.
   */
  public function getCreatedTime();

  /**
   * Sets the favorites creation timestamp.
   *
   * @param int $timestamp
   *   The favorites creation timestamp.
   *
   * @return $this
   */
  public function setCreatedTime($timestamp);

}
