<?php

namespace Drupal\commerce_favorites\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBundleBase;

/**
 * Defines the favorites type entity class.
 *
 * @ConfigEntityType(
 *   id = "commerce_favorites_type",
 *   label = @Translation("Favorites type"),
 *   label_collection = @Translation("Favorites types"),
 *   label_singular = @Translation("favorites type"),
 *   label_plural = @Translation("favorites types"),
 *   label_count = @PluralTranslation(
 *     singular = "@count favorites type",
 *     plural = "@count favorites types",
 *   ),
 *   handlers = {
 *     "form" = {
 *       "add" = "Drupal\commerce_favorites\Form\FavoritesTypeForm",
 *       "edit" = "Drupal\commerce_favorites\Form\FavoritesTypeForm",
 *       "delete" = "Drupal\commerce\Form\CommerceBundleEntityDeleteFormBase"
 *     },
 *     "route_provider" = {
 *       "default" = "Drupal\Core\Entity\Routing\DefaultHtmlRouteProvider",
 *     },
 *     "list_builder" = "Drupal\commerce_favorites\FavoritesTypeListBuilder",
 *   },
 *   admin_permission = "administer commerce_favorites_type",
 *   config_prefix = "commerce_favorites_type",
 *   bundle_of = "commerce_favorites",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   config_export = {
 *     "label",
 *     "id",
 *     "allowAnonymous",
 *   },
 *   links = {
 *     "add-form" = "/admin/commerce/config/favorites-types/add",
 *     "edit-form" = "/admin/commerce/config/favorites-types/{commerce_favorites_type}/edit",
 *     "delete-form" = "/admin/commerce/config/favorites-types/{commerce_favorites_type}/delete",
 *     "collection" = "/admin/commerce/config/favorites-types"
 *   }
 * )
 */
class FavoritesType extends ConfigEntityBundleBase implements FavoritesTypeInterface {

  /**
   * The favorites type ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The favorites type label.
   *
   * @var string
   */
  protected $label;

  /**
   * Whether the favorites item type allows anonymous favorites_lists.
   *
   * @var bool
   */
  protected $allowAnonymous;

  /**
   * {@inheritdoc}
   */
  public function isAllowAnonymous() {
    return $this->allowAnonymous;
  }

  /**
   * {@inheritdoc}
   */
  public function setAllowAnonymous($allow_anonymous) {
    $this->allowAnonymous = $allow_anonymous;
    return $this;
  }

}
