<?php

namespace Drupal\commerce_favorites\Event;

use Drupal\commerce\EventBase;
use Drupal\commerce_favorites\Entity\FavoritesInterface;
use Drupal\user\UserInterface;

/**
 * Defines the favorites assign event.
 *
 * @see \Drupal\commerce_favorites\Event\FavoritesEvents
 */
class FavoritesAssignEvent extends EventBase {

  /**
   * The favorites entity.
   *
   * @var \Drupal\commerce_favorites\Entity\FavoritesInterface
   */
  protected $favorites;

  /**
   * The user account.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $account;

  /**
   * Constructs a new FavoritesAssignEvent.
   *
   * @param \Drupal\commerce_favorites\Entity\FavoritesInterface $favorites
   *   The favorites entity.
   * @param \Drupal\user\UserInterface $account
   *   The user account.
   */
  public function __construct(FavoritesInterface $favorites, UserInterface $account) {
    $this->favorites = $favorites;
    $this->account = $account;
  }

  /**
   * Gets the favorites entity.
   *
   * @return \Drupal\commerce_favorites\Entity\FavoritesInterface
   *   The favorites entity.
   */
  public function getFavorites() {
    return $this->favorites;
  }

  /**
   * Gets the user account.
   *
   * @return \Drupal\user\UserInterface
   *   The user account.
   */
  public function getAccount() {
    return $this->account;
  }

}
