<?php

namespace Drupal\commerce_favorites\Event;

use Drupal\commerce\EventBase;
use Drupal\commerce_favorites\Entity\FavoritesInterface;

/**
 * Defines the favorites empty event.
 *
 * @see \Drupal\commerce_favorites\Event\FavoritesEvents
 */
class FavoritesEmptyEvent extends EventBase {

  /**
   * The favorites entity.
   *
   * @var \Drupal\commerce_favorites\Entity\FavoritesInterface
   */
  protected $favorites;

  /**
   * The removed favorites items.
   *
   * @var \Drupal\commerce_favorites\Entity\FavoritesItemInterface[]
   */
  protected $favoritesItems;

  /**
   * Constructs a new FavoritesEmptyEvent.
   *
   * @param \Drupal\commerce_favorites\Entity\FavoritesInterface $favorites
   *   The favorites entity.
   * @param \Drupal\commerce_favorites\Entity\FavoritesItemInterface[] $favorites_items
   *   The removed favorites items.
   */
  public function __construct(FavoritesInterface $favorites, array $favorites_items) {
    $this->favorites = $favorites;
    $this->favoritesItems = $favorites_items;
  }

  /**
   * Gets the favorites entity.
   *
   * @return \Drupal\commerce_favorites\Entity\FavoritesInterface
   *   The favorites entity.
   */
  public function getFavorites() {
    return $this->favorites;
  }

  /**
   * Gets the removed favorites items.
   *
   * @return \Drupal\commerce_favorites\Entity\FavoritesItemInterface[]
   *   The removed favorites items.
   */
  public function getItems() {
    return $this->favoritesItems;
  }

}
