<?php

namespace Drupal\commerce_favorites\Event;

use Drupal\commerce\EventBase;
use Drupal\commerce_favorites\Entity\FavoritesInterface;
use Drupal\commerce_favorites\Entity\FavoritesItemInterface;

/**
 * Defines the favorites entity toggle event.
 *
 * @see \Drupal\commerce_favorites\Event\FavoritesEvents
 */
class FavoritesEntityToggleEvent extends EventBase {

  /**
   * The favorites entity.
   *
   * @var \Drupal\commerce_favorites\Entity\FavoritesInterface
   */
  protected $favorites;

  /**
   * The destination favorites item.
   *
   * @var \Drupal\commerce_favorites\Entity\FavoritesItemInterface
   */
  protected $favoritesItem;

  /**
   * Constructs a new FavoritesFavoritesItemEvent.
   *
   * @param \Drupal\commerce_favorites\Entity\FavoritesInterface $favorites
   *   The favorites entity.
   * @param \Drupal\commerce_favorites\Entity\FavoritesItemInterface $favorites_item
   *   The destination favorites item.
   */
  public function __construct(FavoritesInterface $favorites, FavoritesItemInterface $favorites_item) {
    $this->favorites = $favorites;
    $this->favoritesItem = $favorites_item;
  }

  /**
   * Gets the favorites entity.
   *
   * @return \Drupal\commerce_favorites\Entity\FavoritesInterface
   *   The favorites entity.
   */
  public function getFavorites() {
    return $this->favorites;
  }

  /**
   * Gets the destination favorites item.
   *
   * @return \Drupal\commerce_favorites\Entity\FavoritesItemInterface
   *   The destination favorites item.
   */
  public function getFavoritesItem() {
    return $this->favoritesItem;
  }

}
