<?php

namespace Drupal\commerce_favorites\Event;

/**
 * Defines events for the favorites module.
 */
final class FavoritesEvents {

  /**
   * Name of the event fired after assigning the anonymous favorites to a user.
   *
   * Fired before the favorites is saved.
   *
   * Use this event to implement logic such as canceling any existing favorites_lists
   * the user might already have prior to the anonymous favorites assignment.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesAssignEvent
   */
  const FAVORITES_ASSIGN = 'commerce_favorites.favorites.assign';

  /**
   * Name of the event fired after emptying the favorites.
   *
   * Fired before the favorites is saved.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesEmptyEvent
   */
  const FAVORITES_EMPTY = 'commerce_favorites.favorites.empty';

  /**
   * Name of the event fired after adding a purchasable entity to the favorites.
   *
   * Fired before the favorites is saved.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesEntityToggleEvent
   */
  const FAVORITES_ENTITY_ADD = 'commerce_favorites.entity.add';

  /**
   * Name of the event fired after removing an item from the favorites.
   *
   * Fired after the favorites item is removed.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesEntityToggleEvent
   */
  const FAVORITES_ENTITY_REMOVE = 'commerce_favorites.entity.remove';

  /**
   * Name of the event fired after loading a favorites.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesEvent
   */
  const FAVORITES_LOAD = 'commerce_favorites.commerce_favorites.load';

  /**
   * Name of the event fired after creating a new favorites.
   *
   * Fired before the favorites is saved.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesEvent
   */
  const FAVORITES_CREATE = 'commerce_favorites.commerce_favorites.create';

  /**
   * Name of the event fired before saving a favorites.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesEvent
   */
  const FAVORITES_PRESAVE = 'commerce_favorites.commerce_favorites.presave';

  /**
   * Name of the event fired after saving a new favorites.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesEvent
   */
  const FAVORITES_INSERT = 'commerce_favorites.commerce_favorites.insert';

  /**
   * Name of the event fired after saving an existing favorites.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesEvent
   */
  const FAVORITES_UPDATE = 'commerce_favorites.commerce_favorites.update';

  /**
   * Name of the event fired before deleting a favorites.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesEvent
   */
  const FAVORITES_PREDELETE = 'commerce_favorites.commerce_favorites.predelete';

  /**
   * Name of the event fired after deleting a favorites.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesEvent
   */
  const FAVORITES_DELETE = 'commerce_favorites.commerce_favorites.delete';

  /**
   * Name of the event fired after loading a favorites item.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesItemEvent
   */
  const FAVORITES_ITEM_LOAD = 'commerce_favorites.commerce_favorites_item.load';

  /**
   * Name of the event fired after creating a favorites item.
   *
   * Fired before the favorites item is saved.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesItemEvent
   */
  const FAVORITES_ITEM_CREATE = 'commerce_favorites.commerce_favorites_item.create';

  /**
   * Name of the event fired before saving a favorites item.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesItemEvent
   */
  const FAVORITES_ITEM_PRESAVE = 'commerce_favorites.commerce_favorites_item.presave';

  /**
   * Name of the event fired after saving a new favorites item.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesItemEvent
   */
  const FAVORITES_ITEM_INSERT = 'commerce_favorites.commerce_favorites_item.insert';

  /**
   * Name of the event fired after saving an existing favorites item.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesItemEvent
   */
  const FAVORITES_ITEM_UPDATE = 'commerce_favorites.commerce_favorites_item.update';

  /**
   * Name of the event fired before deleting a favorites item.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesItemEvent
   */
  const FAVORITES_ITEM_PREDELETE = 'commerce_favorites.commerce_favorites_item.predelete';

  /**
   * Name of the event fired after deleting a favorites item.
   *
   * @Event
   *
   * @see \Drupal\commerce_favorites\Event\FavoritesItemEvent
   */
  const FAVORITES_ITEM_DELETE = 'commerce_favorites.commerce_favorites_item.delete';

}
