<?php

namespace Drupal\commerce_favorites\EventSubscriber;

use Drupal\Core\Messenger\MessengerInterface;
use Drupal\commerce_favorites\Event\FavoritesEntityToggleEvent;
use Drupal\commerce_favorites\Event\FavoritesEvents;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\Core\Url;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Defines the favorites event subscriber.
 *
 * On adding an item to favorites, the "added to favorites" message will be shown.
 */
class FavoritesEventSubscriber implements EventSubscriberInterface {

  use StringTranslationTrait;

  /**
   * The messenger.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Constructs a new FavoritesEventSubscriber object.
   *
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger.
   * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
   *   The string translation.
   */
  public function __construct(MessengerInterface $messenger, TranslationInterface $string_translation) {
    $this->messenger = $messenger;
    $this->stringTranslation = $string_translation;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events = [
      // FavoritesEvents::FAVORITES_ENTITY_ADD => 'displayAddToFavoritesMessage',
      // FavoritesEvents::FAVORITES_ENTITY_REMOVE => 'displayRemoveFromFavoritesMessage',
    ];
    return $events;
  }

  /**
   * Displays an add to favorites message.
   *
   * @param \Drupal\commerce_favorites\Event\FavoritesEntityToggleEvent $event
   *   The add to favorites event.
   */
  public function displayAddToFavoritesMessage(FavoritesEntityToggleEvent $event) {
    $this->messenger->addStatus($this->t('Added to <a href=":url">your Favorites</a>.', [
      ':url' => Url::fromRoute('commerce_favorites.page')->toString(),
    ]));
  }

  /**
   * Displays an removed from favorites message.
   *
   * @param \Drupal\commerce_favorites\Event\FavoritesEntityToggleEvent $event
   *   The remove from favorites event.
   */
  public function displayRemoveFromFavoritesMessage(FavoritesEntityToggleEvent $event) {
    $this->messenger->addStatus($this->t('Removed from <a href=":url">your Favorites</a>.', [
      ':url' => Url::fromRoute('commerce_favorites.page')->toString(),
    ]));
  }

}
