<?php

namespace Drupal\commerce_favorites;

use Drupal\commerce_favorites\Entity\FavoritesInterface;
use Drupal\commerce\PurchasableEntityInterface;
use Drupal\commerce_favorites\Entity\FavoritesItemInterface;

/**
 * Manages the favorites and its favorites items.
 */
interface FavoritesManagerInterface {

  /**
   * Empties the given favorites entity.
   *
   * @param \Drupal\commerce_favorites\Entity\FavoritesInterface $favorites
   *   The favorites entity.
   * @param bool $save_favorites
   *   Whether the favorites should be saved after the operation.
   */
  public function emptyFavorites(FavoritesInterface $favorites, $save_favorites = TRUE);

  /**
   * Adds the given purchasable entity to the given favorites entity.
   *
   * @param \Drupal\commerce_favorites\Entity\FavoritesInterface $favorites
   *   The favorites entity.
   * @param \Drupal\commerce\PurchasableEntityInterface $entity
   *   The purchasable entity.
   * @param int $quantity
   *   The quantity.
   * @param bool $combine
   *   Whether the favorites item should be combined with an existing matching
   *   one.
   * @param bool $save_favorites
   *   Whether the favorites should be saved after the operation.
   *
   * @return \Drupal\commerce_favorites\Entity\FavoritesItemInterface
   *   The saved favorites item.
   */
  public function addEntity(FavoritesInterface $favorites, PurchasableEntityInterface $entity, $quantity = 1, $combine = TRUE, $save_favorites = TRUE);

  /**
   * Merges the source favorites into the target favorites.
   *
   * @param \Drupal\commerce_favorites\Entity\FavoritesInterface $source
   *   The source favorites to merge.
   * @param \Drupal\commerce_favorites\Entity\FavoritesInterface $target
   *   The target favorites.
   * @param bool $save
   *   Save favorites.
   *
   * @return \Drupal\commerce_favorites\Entity\FavoritesInterface
   *   The saved or modified favorites.
   */
  public function merge(FavoritesInterface $source, FavoritesInterface $target, $save = TRUE);

  /**
   * Removes the given favorites item from the favorites entity.
   *
   * @param \Drupal\commerce_favorites\Entity\FavoritesInterface $favorites
   *   The favorites entity.
   * @param \Drupal\commerce_favorites\Entity\FavoritesItemInterface $favorites_item
   *   The favorites item.
   * @param bool $save_favorites
   *   Whether the favorites should be saved after the operation.
   */
  public function removeFavoritesItem(FavoritesInterface $favorites, FavoritesItemInterface $favorites_item, $save_favorites = TRUE);

}
