<?php

namespace Drupal\commerce_favorites;

use Drupal\Core\Session\AccountInterface;

/**
 * Creates and loads favorites_lists for anonymous and authenticated users.
 *
 * @see \Drupal\commerce_favorites\FavoritesSessionInterface
 */
interface FavoritesProviderInterface {

  /**
   * Creates a favorites entity for the given user.
   *
   * @param string $favorites_type
   *   The favorites type ID.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user. If empty, the current user is assumed.
   * @param string $name
   *   The favorites name. Defaults to t('Favorites').
   *
   * @return \Drupal\commerce_favorites\Entity\FavoritesInterface
   *   The created favorites entity.
   *
   * @throws \Drupal\commerce_favorites\Exception\DuplicateFavoritesException
   *   When a favorites with the given criteria already exists.
   */
  public function createFavorites($favorites_type, AccountInterface $account = NULL, $name = NULL);

  /**
   * Gets the favorites entity for the given user.
   *
   * @param string $favorites_type
   *   The favorites type ID.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user. If empty, the current user is assumed.
   *
   * @return \Drupal\commerce_favorites\Entity\FavoritesInterface|null
   *   The favorites entity, or NULL if none found.
   */
  public function getFavorites($favorites_type, AccountInterface $account = NULL);

  /**
   * Gets the favorites entity ID for the given user.
   *
   * @param string $favorites_type
   *   The favorites type ID.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user. If empty, the current user is assumed.
   *
   * @return int|null
   *   The favorites entity ID, or NULL if none found.
   */
  public function getFavoritesId($favorites_type, AccountInterface $account = NULL);

  /**
   * Gets all favorites entities for the given user.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user. If empty, the current user is assumed.
   *
   * @return \Drupal\commerce_favorites\Entity\FavoritesInterface[]
   *   A list of favorites entities.
   */
  public function getFavoritesLists(AccountInterface $account = NULL);

  /**
   * Gets all favorites entity ids for the given user.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user. If empty, the current user is assumed.
   *
   * @return int[]
   *   A list of favorites entity ids.
   */
  public function getFavoritesIds(AccountInterface $account = NULL);

}
