<?php

namespace Drupal\commerce_favorites;

use Symfony\Component\HttpFoundation\Session\SessionInterface;

/**
 * Default implementation of the favorites session.
 */
class FavoritesSession implements FavoritesSessionInterface {

  /**
   * The session.
   *
   * @var \Symfony\Component\HttpFoundation\Session\SessionInterface
   */
  protected $session;

  /**
   * Constructs a new FavoritesSession object.
   *
   * @param \Symfony\Component\HttpFoundation\Session\SessionInterface $session
   *   The session.
   */
  public function __construct(SessionInterface $session) {
    $this->session = $session;
  }

  /**
   * {@inheritdoc}
   */
  public function getFavoritesIds() {
    return $this->session->get('commerce_favorites_lists', []);
  }

  /**
   * {@inheritdoc}
   */
  public function addFavoritesId($favorites_id) {
    $ids = $this->session->get('commerce_favorites_lists', []);
    $ids[] = $favorites_id;
    $this->session->set('commerce_favorites_lists', array_unique($ids));
  }

  /**
   * {@inheritdoc}
   */
  public function hasFavoritesId($favorites_id) {
    $ids = $this->session->get('commerce_favorites_lists', []);
    return in_array($favorites_id, $ids);
  }

  /**
   * {@inheritdoc}
   */
  public function deleteFavoritesId($favorites) {
    $ids = $this->session->get('commerce_favorites_lists', []);
    $ids = array_diff($ids, [$favorites]);
    if (!empty($ids)) {
      $this->session->set('commerce_favorites_lists', $ids);
    }
    else {
      // Remove the empty list to allow the system to clean up empty sessions.
      $this->session->remove('commerce_favorites_lists');
    }
  }

}
