<?php

namespace Drupal\commerce_favorites;

/**
 * Stores favorites ids in the anonymous user's session.
 *
 * Allows the system to keep track of which favorites entities belong to the
 * anonymous user. The session is the only available storage in this case, since
 * all anonymous users share the same user id (0).
 *
 * @see \Drupal\commerce_favorites\FavoritesProviderInterface
 */
interface FavoritesSessionInterface {

  /**
   * Gets all favorites ids from the session.
   *
   * @return int[]
   *   A list of favorites ids.
   */
  public function getFavoritesIds();

  /**
   * Adds the given favorites ID to the session.
   *
   * @param int $favorites_id
   *   The favorites ID.
   */
  public function addFavoritesId($favorites_id);

  /**
   * Checks whether the given favorites ID exists in the session.
   *
   * @param int $favorites_id
   *   The favorites ID.
   *
   * @return bool
   *   TRUE if the given favorites ID exists in the session, FALSE otherwise.
   */
  public function hasFavoritesId($favorites_id);

  /**
   * Deletes the given favorites ID from the session.
   *
   * @param int $favorites_id
   *   The favorites ID.
   */
  public function deleteFavoritesId($favorites_id);

}
