<?php

namespace Drupal\commerce_favorites;

use Drupal\Core\Entity\ContentEntityStorageInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines the interface for favorites storage.
 */
interface FavoritesStorageInterface extends ContentEntityStorageInterface {

  /**
   * Loads the favorites for the given code.
   *
   * @param string $code
   *   The code.
   *
   * @return \Drupal\commerce_favorites\Entity\FavoritesInterface|null
   *   The favorites, or NULL if none found.
   */
  public function loadByCode($code);

  /**
   * Loads the default favorites for the given user.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user.
   * @param string $favorites_type_id
   *   The favorites type ID.
   *
   * @return \Drupal\commerce_favorites\Entity\FavoritesInterface|null
   *   The default favorites for the given, if known.
   */
  public function loadDefaultByUser(AccountInterface $account, $favorites_type_id);

  /**
   * Loads the given user's favorites_lists.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user.
   * @param string $favorites_type_id
   *   The favorites type ID.
   *
   * @return \Drupal\profile\Entity\ProfileInterface[]
   *   The favorites_lists, ordered by ID, descending.
   */
  public function loadMultipleByUser(AccountInterface $account, $favorites_type_id);

}
