<?php

namespace Drupal\commerce_favorites\Form;

use Drupal\commerce_favorites\Entity\FavoritesItemInterface;
use Drupal\Component\Utility\Html;
use Drupal\Core\Ajax\AjaxFormHelperTrait;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\PrependCommand;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\Ajax\CloseDialogCommand;
use Drupal\Core\Cache\Cache;
use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides the favorites details form.
 */
class FavoritesItemDetailsForm extends EntityForm {

  use AjaxFormHelperTrait;

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    /** @var \Drupal\commerce_favorites\Entity\FavoritesItemInterface $favorites_item */
    $favorites_item = $this->entity;

    $form['#tree'] = TRUE;
    $form['#attached']['library'][] = 'core/drupal.dialog.ajax';
    // Workaround for core bug #2897377.
    $form['#id'] = Html::getId($form_state->getBuildInfo()['form_id']);

    $form['comment'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Note'),
      '#rows' => 5,
      '#default_value' => $favorites_item->getComment(),
    ];
    $form['quantity'] = [
      '#type' => 'commerce_number',
      '#title' => $this->t('Quantity'),
      '#required' => TRUE,
      '#default_value' => $favorites_item->getQuantity(),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function actions(array $form, FormStateInterface $form_state) {
    $actions['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save Note'),
      '#submit' => ['::submitForm'],
      '#attributes' => Array(
        'class' => Array('favorites-update-note-button','button','button--primary'),
      ),
    ];
    if ($this->isAjax()) {
      $actions['submit']['#ajax']['callback'] = '::ajaxSubmit';
    }

    return $actions;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    /** @var \Drupal\commerce_favorites\Entity\FavoritesItemInterface $favorites_item */
    $favorites_item = $this->entity;
    $favorites_item->save();

    $favorites = $favorites_item->getFavorites();
    $form_state->setRedirectUrl($favorites->toUrl('user-form'));
  }

  /**
   * {@inheritdoc}
   */
  protected function successfulAjaxSubmit(array $form, FormStateInterface $form_state) {
    // We need to clear parent favorites cache, so that on refresh
    // we are able to see changes also, not only after ajax updates.
    $favorites = $this->entity->getFavorites();
    Cache::invalidateTags($favorites->getCacheTags());

    $response = new AjaxResponse();
    $response->addCommand(new PrependCommand('.commerce-favorites-form', ['#type' => 'status_messages']));
    $response->addCommand(new ReplaceCommand('#favorites-item-details-' . $this->entity->id(), [
      '#theme' => 'commerce_favorites_item_details',
      '#favorites_item_entity' => $this->entity,
    ]));
    $response->addCommand(new CloseDialogCommand());

    return $response;
  }

  /**
   * {@inheritdoc}
   */
  protected function copyFormValuesToEntity(EntityInterface $entity, array $form, FormStateInterface $form_state) {
    assert($entity instanceof FavoritesItemInterface);
    $values = $form_state->getValues();
    unset($values['action']);
    foreach ($values as $key => $value) {
      if ($entity->hasField($key)) {
        $entity->set($key, $value);
      }
    }
  }

}
