<?php

namespace Drupal\commerce_favorites\Form;

use Drupal\commerce_favorites\Mail\FavoritesShareMailInterface;
use Drupal\Component\Utility\Html;
use Drupal\Core\Ajax\AjaxFormHelperTrait;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\PrependCommand;
use Drupal\Core\Ajax\CloseDialogCommand;
use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the favorites share form.
 */
class FavoritesShareForm extends EntityForm {

  use AjaxFormHelperTrait;

  /**
   * The favorites share mail.
   *
   * @var \Drupal\commerce_favorites\Mail\FavoritesShareMailInterface
   */
  protected $favoritesShareMail;

  /**
   * Constructs a new FavoritesUserForm object.
   *
   * @param \Drupal\commerce_favorites\Mail\FavoritesShareMailInterface $favorites_share_mail
   *   The favorites share mail.
   */
  public function __construct(FavoritesShareMailInterface $favorites_share_mail) {
    $this->favoritesShareMail = $favorites_share_mail;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('commerce_favorites.favorites_share_mail')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form['#tree'] = TRUE;
    $form['#attached']['library'][] = 'core/drupal.dialog.ajax';
    // Workaround for core bug #2897377.
    $form['#id'] = Html::getId($form_state->getBuildInfo()['form_id']);

    $form['to'] = [
      '#type' => 'email',
      '#title' => $this->t('Recipient'),
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function actions(array $form, FormStateInterface $form_state) {
    $actions['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Send email'),
      '#submit' => ['::submitForm'],
    ];
    if ($this->isAjax()) {
      $actions['submit']['#ajax']['callback'] = '::ajaxSubmit';
    }

    return $actions;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    /** @var \Drupal\commerce_favorites\Entity\FavoritesInterface $favorites */
    $favorites = $this->entity;
    $to = $form_state->getValue('to');
    $this->favoritesShareMail->send($favorites, $to);

    $this->messenger()->addStatus($this->t('Shared the favorites to @recipient.', [
      '@recipient' => $to,
    ]));
    $form_state->setRedirectUrl($favorites->toUrl('user-form'));
  }

  /**
   * {@inheritdoc}
   */
  protected function successfulAjaxSubmit(array $form, FormStateInterface $form_state) {
    $response = new AjaxResponse();
    $response->addCommand(new PrependCommand('.commerce-favorites-form', ['#type' => 'status_messages']));
    $response->addCommand(new CloseDialogCommand());

    return $response;
  }

}
