<?php

namespace Drupal\commerce_favorites\Mail;

use Drupal\commerce\MailHandlerInterface;
use Drupal\commerce_favorites\Entity\FavoritesInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Defines the favorites share email.
 */
class FavoritesShareMail implements FavoritesShareMailInterface {

  use StringTranslationTrait;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The commerce mail handler.
   *
   * @var \Drupal\commerce\MailHandlerInterface
   */
  protected $mailHandler;

  /**
   * Constructs a new FavoritesShareMail object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   * @param \Drupal\commerce\MailHandlerInterface $mail_handler
   *   The mail handler.
   */
  public function __construct(ConfigFactoryInterface $config_factory, MailHandlerInterface $mail_handler) {
    $this->configFactory = $config_factory;
    $this->mailHandler = $mail_handler;
  }

  /**
   * {@inheritdoc}
   */
  public function send(FavoritesInterface $favorites, $to) {
    $owner = $favorites->getOwner();
    if (!$owner || $owner->isAnonymous()) {
      // Only favorites_lists belonging to authenticated users can be shared.
      return FALSE;
    }

    $subject = $this->t('Check out my @site-name favorites', [
      '@site-name' => $this->configFactory->get('system.site')->get('name'),
    ]);
    $body = [
      '#theme' => 'commerce_favorites_share_mail',
      '#favorites_entity' => $favorites,
    ];
    $params = [
      'id' => 'favorites_share',
      'from' => $owner->getEmail(),
      'favorites' => $favorites,
    ];

    return $this->mailHandler->sendMail($to, $subject, $body, $params);
  }

}
