<?php

namespace Drupal\Tests\commerce_favorites\Kernel\Mail;

use Drupal\commerce_product\Entity\ProductVariation;
use Drupal\commerce_favorites\Entity\Favorites;
use Drupal\commerce_favorites\Entity\FavoritesItem;
use Drupal\Core\Test\AssertMailTrait;
use Drupal\Tests\commerce_favorites\Kernel\FavoritesKernelTestBase;

/**
 * Tests the sending of favorites share emails.
 *
 * @coversDefaultClass \Drupal\commerce_favorites\Mail\FavoritesShareMail
 * @group commerce_favorites
 */
class FavoritesShareMailTest extends FavoritesKernelTestBase {

  use AssertMailTrait;

  /**
   * The favorites share mail.
   *
   * @var \Drupal\commerce_favorites\Mail\FavoritesShareMail
   */
  protected $mail;

  /**
   * A sample user.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $user;

  /**
   * The favorites.
   *
   * @var \Drupal\commerce_favorites\Entity\FavoritesInterface
   */
  protected $favorites;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->config('system.site')
      ->set('name', 'Drupal')
      ->save();

    $this->user = $this->createUser(['mail' => 'customer@example.com']);
    $this->mail = $this->container->get('commerce_favorites.favorites_share_mail');

    $variation = ProductVariation::create([
      'type' => 'default',
      'sku' => strtolower($this->randomMachineName()),
      'price' => [
        'number' => 9.99,
        'currency_code' => 'USD',
      ],
    ]);
    $variation->save();

    $favorites_item = FavoritesItem::create([
      'type' => 'commerce_product_variation',
      'purchasable_entity' => $variation,
      'quantity' => 1,
    ]);
    $favorites_item->save();
    $favorites_item = $this->reloadEntity($favorites_item);

    $this->favorites = Favorites::create([
      'type' => 'default',
      'title' => 'My favorites',
      'uid' => $this->user->id(),
      'favorites_items' => [$favorites_item],
    ]);
    $this->favorites->save();
    $this->favorites = $this->reloadEntity($this->favorites);
  }

  /**
   * @covers ::send
   */
  public function testSend() {
    $this->mail->send($this->favorites, 'test-recipient@example.com');

    $emails = $this->getMails();
    $this->assertEquals(1, count($emails));
    $email = reset($emails);
    $this->assertEquals('text/html; charset=UTF-8;', $email['headers']['Content-Type']);
    $this->assertEquals('commerce_favorites_share', $email['id']);
    $this->assertEquals('test-recipient@example.com', $email['to']);
    $this->assertFalse(isset($email['headers']['Bcc']));
    $this->assertEquals($this->favorites->getOwner()->getEmail(), $email['from']);
    $this->assertEquals('Check out my Drupal favorites', $email['subject']);
    $favorites_url = $this->favorites->toUrl('canonical', ['absolute' => TRUE]);
    $this->assertContains($favorites_url->toString(), $email['body']);
    $this->assertContains('Thanks for having a look!', $email['body']);
  }

}
