<?php

namespace Drupal\Tests\commerce_favorites\Kernel\QueueWorker;

use Drupal\commerce_favorites\Entity\Favorites;
use Drupal\commerce_favorites\Entity\FavoritesItem;
use Drupal\commerce_product\Entity\ProductVariation;
use Drupal\Tests\commerce_cart\Traits\CartManagerTestTrait;
use Drupal\Tests\commerce_favorites\Kernel\FavoritesKernelTestBase;

/**
 * Tests deleting favorites items via cron.
 *
 * @coversDefaultClass \Drupal\commerce_favorites\Plugin\QueueWorker\FavoritesItemDelete
 * @group commerce_favorites
 */
class FavoritesItemDeleteTest extends FavoritesKernelTestBase {

  use CartManagerTestTrait;

  /**
   * A sample user.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $user;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->installCommerceCart();

    $user = $this->createUser();
    $this->user = $this->reloadEntity($user);
  }

  /**
   * Tests deleting favorites items.
   *
   * @covers ::processItem
   */
  public function testDelete() {
    /** @var \Drupal\commerce_product\Entity\ProductVariationInterface $variation */
    $first_variation = ProductVariation::create([
      'type' => 'default',
      'sku' => $this->randomMachineName(),
      'title' => $this->randomString(),
      'status' => 1,
    ]);
    $first_variation->save();

    /** @var \Drupal\commerce_product\Entity\ProductVariationInterface $variation */
    $second_variation = ProductVariation::create([
      'type' => 'default',
      'sku' => $this->randomMachineName(),
      'title' => $this->randomString(),
      'status' => 1,
    ]);
    $second_variation->save();

    /** @var \Drupal\commerce_favorites\Entity\FavoritesItemInterface $favorites_item */
    $first_favorites_item = FavoritesItem::create([
      'type' => 'commerce_product_variation',
      'purchasable_entity' => $first_variation,
    ]);
    $first_favorites_item->save();

    /** @var \Drupal\commerce_favorites\Entity\FavoritesItemInterface $favorites_item */
    $second_favorites_item = FavoritesItem::create([
      'type' => 'commerce_product_variation',
      'purchasable_entity' => $second_variation,
    ]);
    $second_favorites_item->save();

    $favorites = Favorites::create([
      'type' => 'default',
      'name' => 'My favorites',
      'favorites_items' => [$first_favorites_item, $second_favorites_item],
    ]);
    $favorites->save();

    $first_variation->delete();
    $this->container->get('cron')->run();

    // Confirm that the first favorites item has been deleted.
    $first_favorites_item = $this->reloadEntity($first_favorites_item);
    $second_favorites_item = $this->reloadEntity($second_favorites_item);
    $this->assertEmpty($first_favorites_item);
    $this->assertNotEmpty($second_favorites_item);

    /** @var \Drupal\commerce_favorites\Entity\FavoritesInterface $favorites */
    $favorites = $this->reloadEntity($favorites);
    $favorites_items = $favorites->getItems();
    $favorites_item = reset($favorites_items);
    $this->assertCount(1, $favorites_items);
    $this->assertEquals($second_favorites_item->id(), $favorites_item->id());
  }

}
